ChangesTrieConfiguration

Struct ChangesTrieConfiguration 

pub struct ChangesTrieConfiguration {
    pub digest_interval: u32,
    pub digest_levels: u32,
}
Tetcore changes trie configuration.

Fields

digest_interval: u32

Interval (in blocks) at which level1-digests are created. Digests are not created when this is less or equal to 1.

digest_levels: u32

Maximal number of digest levels in hierarchy. 0 means that digests are not created at all (even level1 digests). 1 means only level1-digests are created. 2 means that every digest_interval^2 there will be a level2-digest, and so on. Please ensure that maximum digest interval (i.e. digest_interval^digest_levels) is within u32 limits. Otherwise you’ll never see digests covering such intervals && maximal digests interval will be truncated to the last interval that fits u32 limits.

Implementations

Source

impl ChangesTrieConfiguration

pub fn new(digest_interval: u32, digest_levels: u32) -> Self

Create new configuration given digest interval and levels.

pub fn is_digest_build_enabled(&self) -> bool

Is digest build enabled?

pub fn is_digest_build_required_at_block<Number>( &self, zero: Number, block: Number, ) -> bool
where Number: From<u32> + PartialEq + Rem<Output = Number> + Sub<Output = Number> + PartialOrd + Zero,

Do we need to build digest at given block?

pub fn max_digest_interval(&self) -> u32

Returns max digest interval. One if digests are not created at all.

pub fn prev_max_level_digest_block<Number>( &self, zero: Number, block: Number, ) -> Option<Number>
where Number: Clone + From<u32> + PartialOrd + PartialEq + Add<Output = Number> + Sub<Output = Number> + Div<Output = Number> + Mul<Output = Number> + Zero,

Returns max level digest block number that has been created at block <= passed block number.

Returns None if digests are not created at all.

pub fn next_max_level_digest_range<Number>( &self, zero: Number, block: Number, ) -> Option<(Number, Number)>
where Number: Clone + From<u32> + PartialOrd + PartialEq + Add<Output = Number> + Sub<Output = Number> + Div<Output = Number> + Mul<Output = Number>,

Returns max level digest blocks range (inclusive) which includes passed block.

Returns None if digests are not created at all. It will return the first max-level digest if block is <= zero.

pub fn digest_level_at_block<Number>( &self, zero: Number, block: Number, ) -> Option<(u32, u32, u32)>
where Number: Clone + From<u32> + PartialEq + Rem<Output = Number> + Sub<Output = Number> + PartialOrd + Zero,

Returns Some if digest must be built at given block number. The tuple is: ( digest level digest interval (in blocks) step between blocks we’re interested in when digest is built )